Command line tool that performs various archival tasks.

# Install

```python
curl -fsSL -o sat https://gitlab.sauerburger.com/frank/sit-archive-tool/raw/master/sat
chmod +x sat
sudo cp sat /usr/local/bin
```
<!-- console
```python
$ chmod +x sat
$ test -f /usr/local/bin/sat || cp sat /usr/local/bin
$ cp -a test home
```
-->
# Common tasks

Creating a TAR archive of an existing directory.
<!-- console -->
```
$ sat home -o tar home.tar
```

Creating a compressed TAR archive of an existing directory.
<!-- console -->
```
$ sat home -o gz home.tar.gz
```

**Creating a compressed and encrypted TAR archive of an existing directory.**
```
$ sat home -o gpg home.tar.gz.gpg
```

Hash compressed and encrypted archive.
```
$ sat -H home.tar.gz.gpg
```

List contents of an compressed and encrypted archive.
```
$ sat -i gpg home.tar.gpg -o list
```

Decrypt and decompress archive.
```
$ sat -i gpg home.tar.gz.gpg -o tar home.tar
```

**Restore compressed and encrypted archive.**
```
$ sat -i gpg home.tar.gz.gpg home_restored
```

# Usage

<!-- console_output -->
```console
Usage: /home/esel/bin/sat [-h] [OPTIONS] SOURCE [SOURCE ...] [TARGET]

The SIT Archive Tool performs either of the following processing chains:

  (1) files and dirs -> .tar -> .tar.gz -> tar.gz.gpg -> magnetic tape
  (2) magnetic tape -> tar.gz.gpg -> .tar.gz -> .tar -> files and dirs

Using the command line options allow to specify the beginning and end of the
processing chain. If '/home/user -t /tmp/user.tar' is given, the chain stops
after generating the archive file. The order of the arguments determines whether
a backup is created or restored. The virtual targets -s and -S calculate the
SHA256 checksum at a given stage.

Positional arguments:
  SOURCE
      Used as input. The type of the input is set via --input. If source type is
      'file', there can be multiple SOURCE files or directories.

  TARGET
      Used as output. The type of the output is set via --output. If output type
      is has or list, this argument does not exist.

Options:
  -i --input file|tar|gz|gpg|tape
      If file, source arguments are treated as files and dictionaries to a be
      archived. Multiple source arguments are permitted

      If tar, source argument is trated as TAR archive, usually ending in .tar.

      If gz, source argument is treated as a compressed TAR archive, usually
      ending in .tar.gz.

      If gpg, source argument is treated as an encrypted and compressed TAR
      archive, usually ending in tar.gz.gpg.

      If tape, source argument is treated as a magnetic tape drive, e.g.,
      /dev/nst0.

      If this option is omitted, defaults to 'file'.

      This option cannot be identical to --output option.

  -o --output file|tar|gz|gpg|tape|hash|list
      If file, target argument is treated a directory used to restore the contents
      of the archive. If the directory is created if it doesn't exist.

      If tar, target argument is trated as TAR archive, usually ending in .tar.

      If gz, target argument is treated as a compressed TAR archive, usually
      ending in .tar.gz.

      If gpg, target argument is treated as an encrypted and compressed TAR
      archive, usually ending in tar.gz.gpg. An archive created in this way can be
      shiped to an offsite storage facility.

      If tape, target argument is treated as a magnetic tape drive, e.g.,
      /dev/nst0.

      If hash, computes the hash checksum of the input. All positional arguments
      are treated as SOURCE (TARGET does not exist). If multiple SOURCE files are
      specified, the input type must be 'file' and the --tar or --zip must be
      given.

      If list, print the contents of the archive. TARGET argument does not exist.

      If this option is omitted, defaults to 'file'.

      This option cannot be identical to --output option.

  -x --hex
        Print hex version of sha256 checksum.

  -H --hash
        Performs the conversion specified by '-i' and '-o' but hashs the output
        instaed of writing it. All arguments are treated as sources.

  -b --block SIZE
        If the target is a magnetic tape drive, use the given SIZE as block size.
        Defaults to 1M. Small values lead to slow write speeds and shoe shining.

     --no-hash
        Does not calculate hash before restoring a backup.

     --no-size
        Does not determine size of the input before starting creating or restoring an
        archive. This saves some overhead but disables the ETA information.

  -G --gzip
        Use the single threaded gzip instead of pigz.

  -Z --compression 0-9
        Sets compresssion level from 1 (fast) to 9 (best). If set to 0, disable
        compression.
    
     --no-pipeview
        Disables the use of pipeview. No progress or speed information is printed.

  -v --verbose
        Enables verbose printout.

  -h --help
        Prints this information and exists.

     --version
        Prints the version of this program.
```

